@@ -33,6 +33,7 @@
 #  define KWIDGETSADDONS_DECL_DEPRECATED_NO_EXPORT KWIDGETSADDONS_NO_EXPORT KWIDGETSADDONS_DECL_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KWIDGETSADDONS_NO_DEPRECATED
 #    define KWIDGETSADDONS_NO_DEPRECATED
@@ -84,7 +85,7 @@
 #define KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWIDGETSADDONS_NO_DEPRECATED
-#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
+#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
 #endif
 #ifdef KWIDGETSADDONS_NO_DEPRECATED_WARNINGS
 #  define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +95,7 @@
 #  ifdef KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x56e00
+#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x57400
 #  endif
 #endif
 
